@@ -663,7 +663,7 @@ def JacobianBody(Blist, thetalist):
                   [-1.44321167, 2.94561275,  1.43306521, 0.3]
                   [-2.06639565, 1.82881722, -1.58868628, 0.4]])
     """
-    Jb = np.array(Blist).copy().astype(np.float32)
+    Jb = np.array(Blist).copy().astype(np.float)
     T = np.eye(4)
     for i in range(len(thetalist) - 2, -1, -1):
         T = np.dot(T,MatrixExp6(VecTose3(np.array(Blist)[:, i + 1] \
@@ -769,7 +769,7 @@ def JacobianSpace(Slist, thetalist):
                   [0.2, 0.43654132, -2.43712573,  2.77535713]
                   [0.2, 2.96026613,  3.23573065,  2.22512443]])
     """
-    Js = np.array(Slist).copy().astype(np.float32)
+    Js = np.array(Slist).copy().astype(np.float)
     T = np.eye(4)
     for i in range(1, len(thetalist)):
         T = np.dot(T, MatrixExp6(VecTose3(np.array(Slist)[:, i - 1] \
@@ -1568,9 +1568,9 @@ def ForwardDynamicsTrajectory(thetalist, dthetalist, taumat, g, Ftipmat, \
     """
     taumat = np.array(taumat).T
     Ftipmat = np.array(Ftipmat).T
-    thetamat = taumat.copy().astype(np.float32)
+    thetamat = taumat.copy().astype(np.float)
     thetamat[:, 0] = thetalist
-    dthetamat = taumat.copy().astype(np.float32)
+    dthetamat = taumat.copy().astype(np.float)
     dthetamat[:, 0] = dthetalist
     for i in range(np.array(taumat).shape[1] - 1):
         for j in range(intRes):
@@ -1768,10 +1768,11 @@ def ScrewTrajectory(Xstart, Xend, Tf, N, method,type=0):
             sdot = QuinticTimeScalingDot(Tf, timegap * i)
             sddot = QuinticTimeScalingDdot(Tf, timegap * i)    
         Xs = np.dot(Xstart, MatrixExp6(MatrixLog6(np.dot(TransInv(Xstart),Xend)) * s)) 
-        V = Adjoint(Xs)@se3ToVec(MatrixLog6(TransInv(Xstart)@Xend)); 
-        #V = Adjoint(Xstart) @ se3ToVec(MatrixLog6(TransInv(Xstart) @ Xend));
+        V = se3ToVec(MatrixLog6(TransInv(Xstart)@Xend)); 
         if type == 0  :
-            traj[i] = Xs
+            traj[i] \
+            = np.dot(Xstart, MatrixExp6(MatrixLog6(np.dot(TransInv(Xstart), \
+                                                          Xend)) * s))
         elif type == 1 :
             traj[i] = V*sdot
         elif type == 2 :   
